@@ -11,22 +11,67 @@ from .text import text_to_sequence
 from .commons import intersperse
 from torch import no_grad, LongTensor
 from .utils import *
+from nonebot.log import logger
 
 
-def get_text(text, hps, cleaned=False):
+def check_character(name, tts_gal):
+    index = None
+    config_file = ""
+    model_file = ""
+    for names, model in tts_gal.items():
+        if name in names:
+            config_file = model[0] + ".json"
+            model_file = model[0] + ".pth"
+            index = None if len(model) == 1 else int(model[1])
+            break
+    return config_file, model_file, index
+
+
+def load_language(hps_ms):
+    try:
+        return hps_ms.language
+    except:
+        logger.info("配置文件中缺少language项,请手动添加(新版本内容),具体填写内容请查看github主页\
+            https://github.com/dpm12345/nonebot_plugin_tts_gal/")
+        logger.info("将默认使用日语配置项")
+        return "ja"
+
+
+def load_symbols(hps_ms, lang, symbols_dict):
+    try:
+        symbols = hps_ms.symbols
+    except:
+        logger.info("配置文件中缺失symbols项,建议手动添加")
+        if lang in symbols_dict.keys():
+            logger.info("采用language指定的symbols项")
+            symbols = symbols_dict[lang]
+        else:
+            logger.info("该语言未有默认symbols项，将采用日语symbols")
+            symbols = symbols_dict["ja"]
+    return symbols
+
+
+def get_text(text, hps, symbols, lang, cleaned=False):
     if cleaned:
-        text_norm = text_to_sequence(text, hps.symbols, [])
+        text_norm = text_to_sequence(text, symbols, [], lang)
     else:
-        text_norm = text_to_sequence(text, hps.symbols, hps.data.text_cleaners)
+        text_norm = text_to_sequence(
+            text, symbols, hps.data.text_cleaners, lang)
     if hps.data.add_blank:
         text_norm = intersperse(text_norm, 0)
     text_norm = LongTensor(text_norm)
     return text_norm
-def changeC2E(s:str):
-    return s.replace("。",".").replace("？","?").replace("！","!").replace("，",",")
 
 
-async def translate_youdao(text: str) -> str:
+def changeC2E(s: str):
+    return s.replace("。", ".").replace("？", "?").replace("！", "!").replace("，", ",")
+
+
+def changeE2C(s: str):
+    return s.replace(".", "。").replace("?", "？").replace("!", "！").replace(",", "，")
+
+
+async def translate_youdao(text: str, lang: str) -> str:
     url = f"https://fanyi.youdao.com/translate_o?smartresult=dict&smartresult=rule"
     headers = {
         "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/105.0.0.0 Safari/537.36",
@@ -42,7 +87,7 @@ async def translate_youdao(text: str) -> str:
     data = {
         "i": text,
         "from": "Auto",
-        "to": "ja",
+        "to": lang,
         "smartresult": "dict",
         "client": "fanyideskweb",
         "salt": salt,
